
--[[                                     CurrencyMonitor

This program watches a player's justice points, valor points, conquest points, and honor points
and flashes an alert when any of them exceeds a predetermined threshold. Change the value on 
line 69 to your desired threshold. CurrencyMonitor is meant to be super simple and configurable
only from within this file, meaning you won't find any slash commands or in-game configuration.

                 *** CurrencyMonitor is Copyright 2011 by Phael of Hydraxis ***

Please do not distribute altered copies of this add-on because it can make maintaining it a 
nightmare. If you want to see a feature built into it, please add a comment on the official 
download pages on curse.com and wowinterface.com.

For now, I will take bug reports and feature requests directly in the comments sections of the 
official release channels. Until such a time that I believe I need a ticket tracking system (which
hopefully never happens), I will simply answer bug reports/feature requests in comments sections.

---------------
Version History
---------------

12/2/2011  - V.0.1(BETA) (Initial release)
		   - V.1.0       Now firing on the correct event.
12/5/2011  - V.1.1       Removed BG spamminess through smart points announcement.
12/9/2011  - V.1.2       Spam bug fix. Also warns of only the type of currency that triggered the 
					     warning. Considerable code rewrite for less redundancy.
12/15/2011 - V.1.2.1	 Changed some variables to local to avoid polluting the global environment.
02/24/2012 - V.1.2.2	 Fixed a problem with the currency warning not updating to reflect the
						 current amount of points when points are awarded. Minor .toc file fix.

-----
To-Do
-----

RL Stuff.

--- Credits ---

Credit goes to Wowhead user eidyia for the idea and additional input that helped hone this add-on's
functionality. Specifically, thank eidyia for the version 1.1 removal of BG spam and the 1.2 removal
of buggy spam!

--]]

local currencies = {
	"395", -- Justice points
	"396", -- Valor points
	"392", -- Honor points
	"390"  -- Conquest points
}

local allCurrency = {
	"Justice Points",
	"Valor Points",
	"Honor Points",
	"Conquest Points"
}

local currentAmount = {}

--[[
	Line 74 below holds the threshold at which you want CurrencyMonitor to alert you. After gaining
	a currency, for example Justice Points, if you have more than the value below, this add-on will
	alert you with a raid warning. If you want the raid warning sound, simply remove the --	from the
	beginning of line 98.

	The variable minToWarn (line 75) represents the individual amount for which CM will warn the 
	user. For example, by default honorable kills worth 7 honor will not fire the warning because 
	they are less than 50 (the default value for minToWarn). If you set minToWarn to zero, every 
	honor gain, even 1 point, will spam you. Find a happy medium with this number.
--]]

local maxAmount = 2250
local minToWarn = 50

-- Know what you're doing before you edit anything below this line. --

-- Register the event our invisible frame cares about
function CurrencyMonitor_OnLoad()
	CurrencyMonitorFrame:RegisterEvent("CHAT_MSG_CURRENCY")
end

-- Loop through and get the current amount of the four currencies we care about
local function getAllCurrencies()

	for i = 1, 4 do
		local _, amountNow = GetCurrencyInfo(currencies[i])
		table.insert(currentAmount, amountNow)
	end
end

-- Adds the warning message to the raid warning frame 
local function printOutput(triggerCurrency)
		
	for i = 1, 4 do
		if allCurrency[i] == triggerCurrency then
			--PlaySoundFile("Sound\\Interface\\RaidWarning.wav")
			RaidNotice_AddMessage(RaidWarningFrame, "You have " .. currentAmount[i] .. " " .. allCurrency[i] .. "!", ChatTypeInfo["RAID_WARNING"])
		end
	end
end

-- The function to run when our registered event fires
function CurrencyMonitor_OnEvent(event, arg1)

	if event == "CHAT_MSG_CURRENCY" and tonumber(string.match(arg1, '%d+', -4)) >= minToWarn then
		getAllCurrencies()
		for i = 1, 4 do
			local triggerCurrency = string.match(arg1, allCurrency[i])
			if currentAmount[i] >= maxAmount then
				printOutput(triggerCurrency)
			end
		end
	end
	currentAmount = nil
	currentAmount = {}
end